==> ews-javascript-api-0.1.2.tgz: package/js/Core/Responses/CreateFolderResponse.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var FolderInfo_1 = require("../ServiceObjects/Folders/FolderInfo");
var XmlElementNames_1 = require("../XmlElementNames");
var EwsServiceJsonReader_1 = require("../EwsServiceJsonReader");
var ServiceResult_1 = require("../../Enumerations/ServiceResult");
var ServiceResponse_1 = require("./ServiceResponse");
var CreateFolderResponse = (function (_super) {
    __extends(CreateFolderResponse, _super);
    function CreateFolderResponse(folder) {
        _super.call(this);
        this.folder = null;
        this.folder = folder;
    }
    CreateFolderResponse.prototype.GetObjectInstance = function (service, xmlElementName) {
        if (this.folder != null) {
            return this.folder;
        }
        else {
            var flinfo = new FolderInfo_1.FolderInfo();
            return flinfo.CreateEwsObjectFromXmlElementName(service, xmlElementName);
        }
    };
    CreateFolderResponse.prototype.Loaded = function () {
        if (this.Result == ServiceResult_1.ServiceResult.Success) {
            this.folder.ClearChangeLog();
        }
    };
    CreateFolderResponse.prototype.ReadElementsFromJson = function (responseObject, service) { throw new Error("CreateFolderResponse.ts - ReadElementsFromJson : Not implemented."); };
    CreateFolderResponse.prototype.ReadElementsFromXmlJsObject = function (responseObject, service) {
        _super.prototype.ReadElementsFromXmlJsObject.call(this, responseObject, service);
        if (responseObject[XmlElementNames_1.XmlElementNames.Folders]) {
            var folders = EwsServiceJsonReader_1.EwsServiceJsonReader.ReadServiceObjectsCollectionFromJson(responseObject, service, XmlElementNames_1.XmlElementNames.Folders, this.GetObjectInstance, false, null, false); /* summaryPropertiesOnly */
            this.folder = folders[0];
        }
    };
    return CreateFolderResponse;
})(ServiceResponse_1.ServiceResponse);
exports.CreateFolderResponse = CreateFolderResponse;

==> ews-javascript-api-0.4.0.tgz: package/js/Core/Responses/CreateFolderResponse.js <==
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var FolderInfo_1 = require("../ServiceObjects/Folders/FolderInfo");
var XmlElementNames_1 = require("../XmlElementNames");
var EwsServiceJsonReader_1 = require("../EwsServiceJsonReader");
var ServiceResult_1 = require("../../Enumerations/ServiceResult");
var ServiceResponse_1 = require("./ServiceResponse");
var CreateFolderResponse = (function (_super) {
    __extends(CreateFolderResponse, _super);
    function CreateFolderResponse(folder) {
        _super.call(this);
        this.folder = null;
        this.folder = folder;
    }
    CreateFolderResponse.prototype.GetObjectInstance = function (service, xmlElementName) {
        if (this.folder != null) {
            return this.folder;
        }
        else {
            var flinfo = new FolderInfo_1.FolderInfo();
            return flinfo.CreateEwsObjectFromXmlElementName(service, xmlElementName);
        }
    };
    CreateFolderResponse.prototype.Loaded = function () {
        if (this.Result == ServiceResult_1.ServiceResult.Success) {
            this.folder.ClearChangeLog();
        }
    };
    CreateFolderResponse.prototype.ReadElementsFromJson = function (responseObject, service) { throw new Error("CreateFolderResponse.ts - ReadElementsFromJson : Not implemented."); };
    CreateFolderResponse.prototype.ReadElementsFromXmlJsObject = function (responseObject, service) {
        _super.prototype.ReadElementsFromXmlJsObject.call(this, responseObject, service);
        if (responseObject[XmlElementNames_1.XmlElementNames.Folders]) {
            var folders = EwsServiceJsonReader_1.EwsServiceJsonReader.ReadServiceObjectsCollectionFromJson(responseObject, service, XmlElementNames_1.XmlElementNames.Folders, this.GetObjectInstance, false, /* clearPropertyBag */ null, /* requestedPropertySet */ false); /* summaryPropertiesOnly */
            this.folder = folders[0];
        }
    };
    return CreateFolderResponse;
}(ServiceResponse_1.ServiceResponse));
exports.CreateFolderResponse = CreateFolderResponse;
